==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/igr-radial-column-series.js <==
import { __extends } from "tslib";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialColumnSeries } from "./RadialColumnSeries";
/**
 * Represents a IgxDataChartComponent radial column series.
 * Compare values across categories by using radial rectangles.
*/
var IgrRadialColumnSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRadialColumnSeries, _super);
    function IgrRadialColumnSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrRadialColumnSeries.prototype.createImplementation = function () {
        return new RadialColumnSeries();
    };
    Object.defineProperty(IgrRadialColumnSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialColumnSeries.prototype, "isColumn", {
        /**
         * Gets whether the current series shows a column shape.
        */
        get: function () {
            return this.i.ex;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialColumnSeries.prototype, "isMarkerlessDisplayPreferred", {
        /**
         * Overridden by derived series classes to indicate when marker-less display is preferred or not.
        */
        get: function () {
            return this.i.fj;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialColumnSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.add;
        },
        set: function (v) {
            this.i.add = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialColumnSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.ade;
        },
        set: function (v) {
            this.i.ade = +v;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * When overridden in a derived class, is invoked whenever application code or internal processes
     * call ApplyTemplate.
    
    */
    IgrRadialColumnSeries.prototype.onApplyTemplate = function () {
        this.i.ac();
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrRadialColumnSeries.prototype.getItemSpan = function () {
        var iv = this.i.iu();
        return (iv);
    };
    return IgrRadialColumnSeries;
}(IgrAnchoredRadialSeries));
export { IgrRadialColumnSeries };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/igr-radial-column-series.js <==
import { __extends } from "tslib";
import { IgrAnchoredRadialSeries } from "./igr-anchored-radial-series";
import { RadialColumnSeries } from "./RadialColumnSeries";
/**
 * Represents a IgxDataChartComponent radial column series.
 * Compare values across categories by using radial rectangles.
*/
var IgrRadialColumnSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrRadialColumnSeries, _super);
    function IgrRadialColumnSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrRadialColumnSeries.prototype.createImplementation = function () {
        return new RadialColumnSeries();
    };
    Object.defineProperty(IgrRadialColumnSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialColumnSeries.prototype, "isColumn", {
        /**
         * Gets whether the current series shows a column shape.
        */
        get: function () {
            return this.i.ez;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialColumnSeries.prototype, "isMarkerlessDisplayPreferred", {
        /**
         * Overridden by derived series classes to indicate when marker-less display is preferred or not.
        */
        get: function () {
            return this.i.fl;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialColumnSeries.prototype, "radiusX", {
        /**
         * Gets or sets the x-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.adq;
        },
        set: function (v) {
            this.i.adq = +v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrRadialColumnSeries.prototype, "radiusY", {
        /**
         * Gets or sets the y-radius of the ellipse that is used to round the corners of the column.
        */
        get: function () {
            return this.i.adr;
        },
        set: function (v) {
            this.i.adr = +v;
        },
        enumerable: false,
        configurable: true
    });
    /**
     * When overridden in a derived class, is invoked whenever application code or internal processes
     * call ApplyTemplate.
    
    */
    IgrRadialColumnSeries.prototype.onApplyTemplate = function () {
        this.i.ac();
    };
    /**
     * For a category plotted series, returns the current width of the items within the categories. This only returns a value if the items have some form of width (e.g. columns, bars, etc.) otherwise 0 is returned.
    
    */
    IgrRadialColumnSeries.prototype.getItemSpan = function () {
        var iv = this.i.iw();
        return (iv);
    };
    return IgrRadialColumnSeries;
}(IgrAnchoredRadialSeries));
export { IgrRadialColumnSeries };
